@@ -529,6 +529,18 @@ func TestGetPrinter(t *testing.T) {
 			key:  PlanOutputType,
 			want: &output.VoidPrinter{},
 		},
+		{
+			name: "html stdout output",
+			path: "stdout",
+			key:  HTMLOutputType,
+			want: &output.VoidPrinter{},
+		},
+		{
+			name: "html /dev/stdout output",
+			path: "/dev/stdout",
+			key:  HTMLOutputType,
+			want: &output.VoidPrinter{},
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
