@@ -7,7 +7,7 @@ import (
 	"github.com/snyk/driftctl/test/acceptance"
 )
 
-func TestAcc_AwsRoute53Record_WithFQDNAsId(t *testing.T) {
+func TestAcc_Aws_Route53Record_WithFQDNAsId(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_route53_record"},
@@ -30,13 +30,16 @@ func TestAcc_AwsRoute53Record_WithFQDNAsId(t *testing.T) {
 	})
 }
 
-func TestAcc_AwsRoute53Record_WithAlias(t *testing.T) {
+func TestAcc_Aws_Route53Record_WithAlias(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_route53_record_with_alias"},
 		Args:             []string{"scan", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
+				Env: map[string]string{
+					"AWS_REGION": "us-east-1",
+				},
 				Check: func(result *test.ScanResult, stdout string, err error) {
 					if err != nil {
 						t.Fatal(err)
