@@ -32,12 +32,14 @@ import (
 	"github.com/hashicorp/terraform-exec/tfinstall"
 )
 
+type ShouldRetryFunc func(result *test.ScanResult, retryDuration time.Duration, retryCount uint8) bool
+
 type AccCheck struct {
 	PreExec     func()
 	PostExec    func()
 	Env         map[string]string
 	Args        func() []string
-	ShouldRetry func(result *test.ScanResult, retryDuration time.Duration, retryCount uint8) bool
+	ShouldRetry ShouldRetryFunc
 	Check       func(result *test.ScanResult, stdout string, err error)
 }
 
@@ -47,6 +49,7 @@ type RetryConfig struct {
 }
 
 type AccTestCase struct {
+	DoNotRunTerraform          bool
 	TerraformVersion           string
 	WorkingDir                 string
 	Paths                      []string
@@ -113,7 +116,7 @@ func (c *AccTestCase) validate() error {
 		return fmt.Errorf("checks attribute must be defined")
 	}
 
-	if len(c.Paths) < 1 {
+	if len(c.Paths) < 1 && !c.DoNotRunTerraform {
 		return fmt.Errorf("Paths attribute must be defined")
 	}
 
@@ -344,29 +347,31 @@ func Run(t *testing.T, c AccTestCase) {
 	checkpoint := os.Getenv("CHECKPOINT_DISABLE")
 	os.Setenv("CHECKPOINT_DISABLE", "true")
 
-	// Execute terraform init if .terraform folder is not found in test folder
-	err := c.terraformInit()
-	if err != nil {
-		t.Fatal(err)
-	}
-
-	defer func() {
-		c.restoreEnv()
-		err := c.terraformDestroy()
-		os.Setenv("CHECKPOINT_DISABLE", checkpoint)
+	if !c.DoNotRunTerraform {
+		// Execute terraform init if .terraform folder is not found in test folder
+		err := c.terraformInit()
 		if err != nil {
 			t.Fatal(err)
 		}
-	}()
 
-	err = c.terraformApply()
-	if err != nil {
-		t.Fatal(err)
-	}
+		defer func() {
+			c.restoreEnv()
+			err := c.terraformDestroy()
+			os.Setenv("CHECKPOINT_DISABLE", checkpoint)
+			if err != nil {
+				t.Fatal(err)
+			}
+		}()
 
-	err = c.createResultFile(t)
-	if err != nil {
-		t.Fatal(err)
+		err = c.terraformApply()
+		if err != nil {
+			t.Fatal(err)
+		}
+
+		err = c.createResultFile(t)
+		if err != nil {
+			t.Fatal(err)
+		}
 	}
 
 	// If the path contains only one element, we switch to this directory for driftctl execution
@@ -393,9 +398,11 @@ func Run(t *testing.T, c AccTestCase) {
 				)
 			}
 		}
-		c.Args = append(c.Args,
-			"--output", fmt.Sprintf("json://%s", c.getResultFilePath()),
-		)
+		if c.getResultFilePath() != "" {
+			c.Args = append(c.Args,
+				"--output", fmt.Sprintf("json://%s", c.getResultFilePath()),
+			)
+		}
 	}
 
 	for _, check := range c.Checks {
@@ -421,7 +428,7 @@ func Run(t *testing.T, c AccTestCase) {
 		wd, _ := os.Getwd()
 		if c.WorkingDir != "" {
 			logrus.WithField("dir", c.WorkingDir).Debug("Switching working directory for driftctl execution")
-			err = os.Chdir(c.WorkingDir)
+			err := os.Chdir(c.WorkingDir)
 			if err != nil {
 				logrus.WithFields(logrus.Fields{
 					"from": wd,
@@ -438,14 +445,17 @@ func Run(t *testing.T, c AccTestCase) {
 			if check.ShouldRetry == nil || !check.ShouldRetry(result, time.Since(timeBeforeRetry), retryCount) {
 				break
 			}
-			logrus.WithField("count", fmt.Sprintf("%d", retryCount)).Debug("Retrying scan ...")
+			logrus.
+				WithField("count", fmt.Sprintf("%d", retryCount)).
+				WithField("retry_duration", time.Since(timeBeforeRetry).Round(time.Second)).
+				Debug("Retrying scan ...")
 			_, _, _ = runDriftCtlCmd(driftctlCmd)
 			result = c.getResult(t)
 			retryCount++
 		}
 		// Restore original working directory
 		if c.WorkingDir != "" {
-			err = os.Chdir(wd)
+			err := os.Chdir(wd)
 			if err != nil {
 				logrus.WithFields(logrus.Fields{
 					"to":   wd,
@@ -496,3 +506,16 @@ func RetryFor(timeout time.Duration, f func(c chan struct{}) error) error {
 		return ctx.Err()
 	}
 }
+
+// LinearBackoff returns a function that retries using
+// a back-off strategy of retrying 'n' times and doubling the
+// amount of time waited after each one.
+func LinearBackoff(limit time.Duration) ShouldRetryFunc {
+	return func(result *test.ScanResult, retryDuration time.Duration, retryCount uint8) bool {
+		if result.IsSync() || retryDuration > limit {
+			return false
+		}
+		time.Sleep((2 * time.Duration(retryCount)) * time.Minute)
+		return true
+	}
+}
